;*****************************************************************
;       BIN2BCD (8 bit binary to BCD conversion subroutine)
;
;       This routine converts the 8 bit number in W to its BCD
;	equivalent with values 0 - 9 stored in HUND, TEN, & ONE
;	registers.
;
;	Usefull when binary data is to be converted into a user
;	readable format (use BCD2ASC to convert BCD values to
;	ASCII characters for display on a LCD or for serial 
;	transmission)
;
;	Input: 8 bit binary number in W register
;	Output: BCD values in HUND, TEN, & ONE registers
;
;	Requires: HUND, TEN, & ONE registers defined. 
;
;	Executed by:
;
;	MOVF	[REGISTER NAME],W
;	CALL	BIN2BCD
;
;	or
;
;	MOVLW	0xNN
;	CALL	BIN2BCD
;
;	DH MicroSystems, Inc.
;	WWW.DHMICRO.COM
;
;*****************************************************************
BIN2BCD	MOVWF	ONE
	CLRF	TEN
	CLRF	HUND		; init registers

H1	MOVLW	0x64		; 100
	SUBWF	ONE,F		; subtract 100 from number
	BTFSC	STATUS,C	; negative result?
	GOTO	H2		; no? goto H2
	GOTO	H3		; yes? goto H3 (100's done)
H2	INCF	HUND,F		; increment HUND register
	GOTO	H1		; & loop back for another test
H3	MOVLW	0x64		; 100
	ADDWF	ONE,F		; add 100 back to number

T1	MOVLW	0x0A		; 10
	SUBWF	ONE,F		; subtract 10 from number
	BTFSC	STATUS,C	; negative result?
	GOTO	T2		; no? goto T2
	GOTO	T3		; yes? goto T3 (10's done)
T2	INCF	TEN,F		; increment TEN register
	GOTO	T1		; & loop back for another test
T3	MOVLW	0x0A		; 10
	ADDWF	ONE,F		; add 10 back to number

	RETLW	0